#include <fmain.h>
#include <faddfiles.h>
#include <fsettings.h>
#include <QMessageBox>
#include <QtDebug>

FMain::FMain(QWidget * parent, Qt::WFlags f) : QMainWindow(parent, f)
{
 QTextCodec::setCodecForTr (QTextCodec::codecForName ("UTF-8"));
 ui.setupUi(this);
 setWindowTitle("Rapidget");
 /* Zrob menu dla ikonki w zasobniku */
 mTrayMenuExit = new QAction(this);
 mTrayMenuExit->setObjectName(QString::fromUtf8("menuTrayExit"));
 mTrayMenuExit->setText(tr("Wyjdź"));

 mTrayMenuShowHide = new QAction(this);
 mTrayMenuShowHide->setObjectName(QString::fromUtf8("menuTrayShowHide"));
 mTrayMenuShowHide->setText(tr("Pokaż/Ukryj"));

 mTrayMenuSettings = new QAction(this);
 mTrayMenuSettings->setObjectName(QString::fromUtf8("menuTraySettings"));
 mTrayMenuSettings->setText(tr("Ustawienia"));

 mTrayMenu = new QMenu();
 mTrayMenu->addAction(mTrayMenuShowHide);
 mTrayMenu->addAction(mTrayMenuSettings);
 mTrayMenu->addSeparator();
 mTrayMenu->addAction(mTrayMenuExit);

  /* Pokaz ikonke w zasobniku systemowym */
 mTrayIcon = new QSystemTrayIcon(QIcon(":/icon.png"), this);
 mTrayIcon->setVisible(true);
 mTrayIcon->setContextMenu(mTrayMenu);

 /* Polacz sygnaly ze slotami */
 connect(ui.menuAddFiles, SIGNAL(triggered()), this, SLOT(addFiles()));
 connect(ui.menuSettings, SIGNAL(triggered()), this, SLOT(settings()));
 connect(mTrayMenuExit, SIGNAL(triggered()), this, SLOT(close()));
 connect(mTrayMenuShowHide, SIGNAL(triggered()), this, SLOT(traySupport()));
 connect(mTrayMenuSettings, SIGNAL(triggered()), this, SLOT(settings()));
 connect(mTrayIcon, SIGNAL(activated(QSystemTrayIcon::ActivationReason)), this, SLOT(traySupport(QSystemTrayIcon::ActivationReason)));

 /* TODO: Wczytaj konfiguracje */
 mOutDir = "~/tmp";
 mParallelDownloads = 4;

}

FMain::~FMain()
{
 delete mTrayIcon;
 delete mTrayMenu;
 delete mTrayMenuExit;
 delete mTrayMenuShowHide;
 delete mTrayMenuSettings;
}

void FMain::addFiles()
{
 int i;
 QStringList links;
 QString link;
 FAddFiles * wnd = new FAddFiles;

 wnd->exec();
 if (wnd->result() == QDialog::Accepted)
 {
  links = wnd->ui.textLinks->toPlainText().split('\n');
  for(i=0;i<links.size();i++)
  {
   link = links.at(i).toLocal8Bit().constData();
   if (link.count(QRegExp("http\\://(.*\\.)?rapidshare.com/files/([0-9]*)/(.*)")) != 1)
      continue;
   qDebug() << "Dodaje link " << link;

  }
 }
 delete wnd;
}

void FMain::traySupport(QSystemTrayIcon::ActivationReason reason)
{
 if (reason == QSystemTrayIcon::DoubleClick)
    setVisible(!isVisible());
}

void FMain::settings()
{
 FSettings * wnd = new FSettings;

 if (!isVisible())
    setVisible(true);

 wnd->ui.textOutput->setText(mOutDir);
 wnd->ui.sbParallelDownloads->setValue(mParallelDownloads);
 wnd->ui.textLogin->setText(mLogin);
 wnd->ui.textPasswd->setText(mPasswd);
 if (mPremiumUser)
   wnd->ui.cbPremium->setCheckState(Qt::Checked);
 else
   wnd->ui.cbPremium->setCheckState(Qt::Unchecked);

 wnd->exec();

 if (wnd->result() == QDialog::Accepted)
 {
  if (wnd->ui.cbPremium->checkState() == Qt::Checked)
     mPremiumUser = true;
  else
     mPremiumUser = false;
  mOutDir = wnd->ui.textOutput->text();
  mLogin = wnd->ui.textLogin->text();
  mPasswd = wnd->ui.textPasswd->text();
  mParallelDownloads = wnd->ui.sbParallelDownloads->value();
 }
 delete wnd;
}
